.. image:: images/deux_banner_text.png
  :width: 524
  :height: 207

**Multifactor Authentication for Django Rest Framework**

==============
 Introduction
==============

.. include:: includes/introduction.txt
.. include:: includes/start.txt
.. include:: includes/installation.txt
.. include:: includes/resources.txt
